@@ -10,10 +10,6 @@ module Puppet
       Puppet::Network::HTTP::MASTER_URL_PREFIX
     end
 
-    def self.ca_url_prefix
-      Puppet::Network::HTTP::CA_URL_PREFIX
-    end
-
     def self.default_acl
       [
       # Master API V3
@@ -28,15 +24,6 @@ module Puppet
       { :acl => "#{master_url_prefix}/v3/file" },
 
       { :acl => "#{master_url_prefix}/v3/status", :method => [:find], :authenticated => true },
-
-      # CA API V1
-      { :acl => "#{ca_url_prefix}/v1/certificate_revocation_list/ca", :method => :find, :authenticated => true },
-
-      # These allow `auth any`, because if you can do them anonymously you
-      # should probably also be able to do them when trusted.
-      { :acl => "#{ca_url_prefix}/v1/certificate/ca", :method => :find, :authenticated => :any },
-      { :acl => "#{ca_url_prefix}/v1/certificate/", :method => :find, :authenticated => :any },
-      { :acl => "#{ca_url_prefix}/v1/certificate_request", :method => [:find, :save], :authenticated => :any },
       ]
     end
 
