@@ -29,7 +29,7 @@ module LoaderPaths
           result << FunctionPath3x.new(loader)
         end
     when :plan
-      result << PlanPathPP.new(loader)
+      result << PlanPath.new(loader)
     when :task
       result << TaskPath.new(loader) if Puppet[:tasks] && loader.loadables.include?(:task)
     when :type
@@ -312,27 +312,51 @@ module LoaderPaths
     end
   end
 
-  class PlanPathPP < PuppetSmartPath
-    PLAN_PATH_PP = File.join('plans')
+  class PlanPath < PuppetSmartPath
+    PLAN_PATH = File.join('plans')
+    PP_EXT = '.pp'.freeze
+    YAML_EXT = '.yaml'.freeze
+
+    def initialize(loader)
+      super
+
+      if Puppet.lookup(:yaml_plan_instantiator) { nil }
+        @extensions = [PP_EXT, YAML_EXT]
+      else
+        @extensions = [PP_EXT]
+      end
+      @init_filenames = @extensions.map { |ext| "init#{ext}" }
+    end
+
+    def extension
+      EMPTY_STRING
+    end
 
     def relative_path
-      PLAN_PATH_PP
+      PLAN_PATH
     end
 
     def instantiator()
-      Puppet::Pops::Loader::PuppetPlanInstantiator
+      Puppet::Pops::Loader::GenericPlanInstantiator
+    end
+
+    def fuzzy_matching?
+      true
+    end
+
+    def valid_path?(path)
+      @extensions.any? { |ext| path.end_with?(ext) } && path.start_with?(generic_path)
     end
 
     def typed_name(type, name_authority, relative_path, module_name)
-      if relative_path == 'init.pp' && !(module_name.nil? || module_name.empty?)
+      if @init_filenames.include?(relative_path) && !(module_name.nil? || module_name.empty?)
         TypedName.new(type, module_name, name_authority)
       else
         n = ''
         n << module_name unless module_name.nil?
-        unless extension.empty?
-          # Remove extension
-          relative_path = relative_path[0..-(extension.length+1)]
-        end
+        ext = @extensions.find { |extension| relative_path.end_with?(extension) }
+        relative_path = relative_path[0..-(ext.length+1)]
+
         relative_path.split('/').each do |segment|
           n << '::' if n.size > 0
           n << segment
@@ -340,6 +364,18 @@ module LoaderPaths
         TypedName.new(type, n, name_authority)
       end
     end
+
+    def effective_path(typed_name, start_index_in_name)
+      # Puppet name to path always skips the name-space as that is part of the generic path
+      # i.e. <module>/mymodule/functions/foo.pp is the function mymodule::foo
+      parts = typed_name.name_parts
+      if start_index_in_name > 0
+        return nil if start_index_in_name >= parts.size
+        parts = parts[start_index_in_name..-1]
+      end
+      basename = File.join(generic_path, parts)
+      @extensions.map { |ext| "#{basename}#{ext}" }
+    end
   end
 
   # SmartPaths
