@@ -1,4 +1,3 @@
-# coding: utf-8
 # Define the different packaging systems.  Each package system is implemented
 # in a module, which then gets used to individually extend each package object.
 # This allows packages to exist on the same machine using different packaging
@@ -21,8 +20,8 @@ module Puppet
       requires in order to function, and you must meet those requirements
       to use a given provider.
 
-      You can declare multiple package resources with the same `name` as long
-      as they have unique titles, and specify different providers and commands.
+      You can declare multiple package resources with the same `name`, as long
+      as they specify different providers and have unique titles.
 
       Note that you must use the _title_ to make a reference to a package
       resource; `Package[<NAME>]` is not a synonym for `Package[<TITLE>]` like
@@ -57,7 +56,6 @@ module Puppet
         a user or another package. Held is considered a superset of
         installed.",
       :methods => [:hold]
-    feature :install_only, "The provider accepts options to only install packages never update (kernels, etc.)"
     feature :install_options, "The provider accepts options to be
       passed to the installer command."
     feature :uninstall_options, "The provider accepts options to be
@@ -68,8 +66,6 @@ module Puppet
       :methods => [:package_settings_insync?, :package_settings, :package_settings=]
     feature :virtual_packages, "The provider accepts virtual package names for install and uninstall."
 
-    feature :targetable, "The provider accepts a targeted package management command."
-
     ensurable do
       desc <<-EOT
         What state the package should be in. On packaging systems that can
@@ -275,55 +271,24 @@ module Puppet
     providify
     paramclass(:provider).isnamevar
 
-    # Specify a targeted package management command.
-    newparam(:command, :required_features => :targetable) do
-      desc <<-EOT
-        The targeted command to use when managing a package:
-
-          package { 'mysql':
-            provider => gem,
-          }
-
-          package { 'mysql-opt':
-            name     => 'mysql',
-            provider => gem,
-            command  => '/opt/ruby/bin/gem',
-          }
-
-        Each provider defines a package management command; and uses the first
-        instance of the command found in the PATH.
-
-        Providers supporting the targetable feature allow you to specify the
-        absolute path of the package management command; useful when multiple
-        instances of the command are installed, or the command is not in the PATH.
-      EOT
-
-      isnamevar
-      defaultto :default
+    def self.parameters_to_include
+      [:provider]
     end
 
-    # We have more than one namevar, so we need title_patterns.
-    # However, we cheat and set the patterns to map to name only
-    # and completely ignore provider (and command, for targetable providers).
-    # So far, the logic that determines uniqueness appears to just
-    # "Do The Right Thing™" when provider (and command) are explicitly set.
+    # We have more than one namevar, so we need title_patterns. However, we
+    # cheat and set the patterns to map to name only and completely ignore
+    # provider. So far, the logic that determines uniqueness appears to just
+    # "Do The Right Thing™" when the provider is explicitly set by the user.
     #
     # The following resources will be seen as unique by puppet:
     #
     #     # Uniqueness Key: ['mysql', nil]
-    #     package {'mysql': }
+    #     package{'mysql': }
     #
-    #     # Uniqueness Key: ['mysql', 'gem', nil]
-    #     package {'gem-mysql':
-    #       name     => 'mysql,
-    #       provider => gem,
-    #     }
-    #
-    #     # Uniqueness Key: ['mysql', 'gem', '/opt/ruby/bin/gem']
-    #     package {'gem-mysql-opt':
+    #     # Uniqueness Key: ['mysql', 'gem']
+    #     package{'gem-mysql':
     #       name     => 'mysql,
     #       provider => gem
-    #       command  => '/opt/ruby/bin/gem',
     #     }
     #
     # This does not handle the case where providers like 'yum' and 'rpm' should
@@ -481,16 +446,8 @@ module Puppet
     end
 
     newparam(:flavor) do
-      desc "OpenBSD and DNF modules support 'flavors', which are
-        further specifications for which type of package you want."
-    end
-
-    newparam(:install_only, :boolean => false, :parent => Puppet::Parameter::Boolean, :required_features => :install_only) do
-      desc <<-EOT
-        It should be set for packages that should only ever be installed,
-        never updated. Kernels in particular fall into this category.
-      EOT
-      defaultto false
+      desc "OpenBSD supports 'flavors', which are further specifications for
+        which type of package you want."
     end
 
     newparam(:install_options, :parent => Puppet::Parameter::PackageOptions, :required_features => :install_options) do
